Crypto Loans Endpoints
======================

Get Crypto Loans Income History (USER_DATA)
-------------------------------------------
.. autofunction:: binance.spot.Spot.loan_history

Get Loan Borrow History (USER_DATA)
-----------------------------------
.. autofunction:: binance.spot.Spot.loan_borrow_history

Get Loan Repayment History (USER_DATA)
--------------------------------------
.. autofunction:: binance.spot.Spot.loan_repay_history

Get Loan LTV Adjustment History (USER_DATA)
-------------------------------------------
.. autofunction:: binance.spot.Spot.loan_adjust_ltv_history

Get VIP Loan Ongoing Orders (USER_DATA)
---------------------------------------
.. autofunction:: binance.spot.Spot.loan_vip_ongoing_orders

VIP Loan Repay (TRADE)
----------------------
.. autofunction:: binance.spot.Spot.loan_vip_repay

Get VIP Loan Repayment History (USER_DATA)
------------------------------------------
.. autofunction:: binance.spot.Spot.loan_vip_repay_history

Check Locked Value of VIP Collateral Account (USER_DATA)
--------------------------------------------------------
.. autofunction:: binance.spot.Spot.loan_vip_collateral_account

Get Loanable Assets Data (USER_DATA)
------------------------------------
.. autofunction:: binance.spot.Spot.loan_loanable_data
